@@ -335,7 +335,6 @@ ev_sidebar_init (EvSidebar *ev_sidebar)
 	GtkWidget *close_button;
 	GtkWidget *select_hbox;
 	GtkWidget *arrow;
-	GtkWidget *image;
 
 	ev_sidebar->priv = EV_SIDEBAR_GET_PRIVATE (ev_sidebar);
 
@@ -348,7 +347,11 @@ ev_sidebar_init (EvSidebar *ev_sidebar)
 					    G_TYPE_INT);
 
 	/* top option menu */
-	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
+	gtk_widget_set_margin_top (hbox, 2);
+	gtk_widget_set_margin_bottom (hbox, 2);
+	gtk_widget_set_margin_start (hbox, 2);
+	gtk_widget_set_margin_end (hbox, 2);
 	ev_sidebar->priv->hbox = hbox;
 	gtk_box_pack_start (GTK_BOX (ev_sidebar), hbox, FALSE, FALSE, 0);
 	gtk_widget_show (hbox);
@@ -380,17 +383,11 @@ ev_sidebar_init (EvSidebar *ev_sidebar)
 	gtk_box_pack_start (GTK_BOX (hbox), ev_sidebar->priv->select_button, TRUE, TRUE, 0);
 	gtk_widget_show (ev_sidebar->priv->select_button);
 
-	close_button = gtk_button_new ();
+        close_button = gtk_button_new_from_icon_name ("window-close-symbolic", GTK_ICON_SIZE_BUTTON);
 	gtk_button_set_relief (GTK_BUTTON (close_button), GTK_RELIEF_NONE);
 	g_signal_connect (close_button, "clicked",
 			  G_CALLBACK (ev_sidebar_close_clicked_cb),
 			  ev_sidebar);
-	   
-	image = gtk_image_new_from_stock (GTK_STOCK_CLOSE,
-					  GTK_ICON_SIZE_MENU);
-	gtk_container_add (GTK_CONTAINER (close_button), image);
-	gtk_widget_show (image);
-   
 	gtk_box_pack_end (GTK_BOX (hbox), close_button, FALSE, FALSE, 0);
 	gtk_widget_show (close_button);
    
@@ -484,6 +481,16 @@ ev_sidebar_add_page (EvSidebar   *ev_sidebar,
 	g_free (label_title);
 }
 
+static gboolean
+ev_sidebar_current_page_support_document (EvSidebar  *sidebar,
+                                          EvDocument *document)
+{
+	GtkWidget *current_page = ev_sidebar_get_current_page (sidebar);
+
+	return ev_sidebar_page_support_document (EV_SIDEBAR_PAGE (current_page), document);
+}
+
+
 static void
 ev_sidebar_document_changed_cb (EvDocumentModel *model,
 				GParamSpec      *pspec,
@@ -493,7 +500,7 @@ ev_sidebar_document_changed_cb (EvDocumentModel *model,
 	EvDocument *document = ev_document_model_get_document (model);
 	GtkTreeIter iter;
 	gboolean valid;
-	gboolean has_pages = FALSE;
+	GtkWidget *first_supported_page = NULL;
 
 	for (valid = gtk_tree_model_get_iter_first (priv->page_model, &iter);
 	     valid;
@@ -507,7 +514,9 @@ ev_sidebar_document_changed_cb (EvDocumentModel *model,
 				    -1);
 
 		if (ev_sidebar_page_support_document (EV_SIDEBAR_PAGE (widget),	document)) {
-			has_pages = TRUE;
+			gtk_widget_set_sensitive (menu_widget, TRUE);
+			if (!first_supported_page)
+                                first_supported_page = widget;
 		} else {
 			gtk_widget_set_sensitive (menu_widget, FALSE);
 		}
@@ -515,11 +524,14 @@ ev_sidebar_document_changed_cb (EvDocumentModel *model,
 		g_object_unref (menu_widget);
 	}
 
-	if (!has_pages) {
-		gtk_widget_hide (GTK_WIDGET (sidebar));
-	} else {
+	if (first_supported_page != NULL) {
+		if (!ev_sidebar_current_page_support_document (sidebar, document)) {
+			ev_sidebar_set_page (sidebar, first_supported_page);
+		}
 		gtk_widget_set_sensitive (GTK_WIDGET (sidebar->priv->notebook), TRUE);
 		gtk_widget_set_sensitive (GTK_WIDGET (sidebar->priv->select_button), TRUE);
+	} else {
+		gtk_widget_hide (GTK_WIDGET (sidebar));
 	}
 }
 
